@@ -465,6 +465,7 @@ class BaseSchema(base.SchemaABC):
 
         .. versionadded:: 1.0.0
         """
+        errors = {}
         many = self.many if many is None else bool(many)
         if not many and utils.is_collection(obj) and not utils.is_keyed_tuple(obj):
             warnings.warn('Implicit collection handling is deprecated. Set '
@@ -483,8 +484,6 @@ class BaseSchema(base.SchemaABC):
         except ValidationError as error:
             errors = error.normalized_messages()
             result = None
-        else:
-            errors = {}
 
         if not errors:
             if update_fields:
@@ -504,10 +503,6 @@ class BaseSchema(base.SchemaABC):
             except ValidationError as error:
                 errors = self._marshal.errors
                 preresult = error.data
-                if self.strict:
-                    raise error
-            else:
-                errors = {}
 
             result = self._postprocess(preresult, many, obj=obj)
 
@@ -519,12 +514,21 @@ class BaseSchema(base.SchemaABC):
                     many,
                     original_data=obj)
             except ValidationError as error:
-                errors.update(error.normalized_messages())
+                errors = error.normalized_messages()
         if errors:
             # TODO: Remove self.__error_handler__ in a later release
-            error_handler = self.handle_error or self.__error_handler__
-            if callable(error_handler):
-                error_handler(errors, obj)
+            if self.__error_handler__ and callable(self.__error_handler__):
+                self.__error_handler__(errors, obj)
+            exc = ValidationError(
+                errors,
+                field_names=self._marshal.error_field_names,
+                fields=self._marshal.error_fields,
+                data=obj,
+                **self._marshal.error_kwargs
+            )
+            self.handle_error(exc, obj)
+            if self.strict:
+                raise exc
 
         return MarshalResult(result, errors)
 
@@ -616,6 +620,7 @@ class BaseSchema(base.SchemaABC):
         :param bool postprocess: Whether to run post_load methods..
         :return: A tuple of the form (`data`, `errors`)
         """
+        errors = {}
         many = self.many if many is None else bool(many)
         if partial is None:
             partial = self.partial
@@ -628,8 +633,6 @@ class BaseSchema(base.SchemaABC):
         except ValidationError as err:
             errors = err.normalized_messages()
             result = None
-        else:
-            errors = {}
         if not errors:
             try:
                 result = self._unmarshal(
@@ -642,8 +645,6 @@ class BaseSchema(base.SchemaABC):
                 )
             except ValidationError as error:
                 result = error.data
-            else:
-                errors = {}
             self._invoke_field_validators(data=result, many=many)
             errors = self._unmarshal.errors
             field_errors = bool(errors)
@@ -667,7 +668,7 @@ class BaseSchema(base.SchemaABC):
                     many,
                     original_data=data)
             except ValidationError as err:
-                errors.update(err.normalized_messages())
+                errors = err.normalized_messages()
         if errors:
             # TODO: Remove self.__error_handler__ in a later release
             if self.__error_handler__ and callable(self.__error_handler__):
